==> yanmah2-1.5-noarch.zip: yanmah2-1.5-noarch/configurable_variables.php <==
<?php
//YANMAH2 - Yet ANother Mobile Accelerated HatenaHaiku
//(c) 2010 YANMAH2 project
//This program is freesoftware. you can redistribute it and/ormodify it under the terms of the [GNU Affero GPL v3](http://www.gnu.org/licenses/agpl.html).
?>
<?php defined("HELLO") or exit(); ?>
<?php
//****************************************************
//このプログラムを設置・管理する責任者名を記入する。
$admin_name = "ここに設置者の名前を記入";
//上の設置者と連絡をとる手段、またはその情報を含む URLを記入する。
$admin_url = "http://h.example.ne.jp/user/";
//****************************************************
//エントリの表示文字数制限の基準値（文字幅）
$entry_limit = 560;
//インクルードパスの設定。"default" でシステムの設定をそのまま使用する。
//パスを記入するとそのパスが追加される。
$extra_include_path = "default";
//モバイルゲートウェイの URL
$mobile_gateway = "http://www.google.co.jp/gwt/n?u=";
//ハイク公式の URL
$haiku_official_url = "http://h1beta.hatena.ne.jp/mobile/";
//API のベース URL
$api_base_url = "http://h1beta.hatena.ne.jp/api/";
//OAuth コンシューマキー
$conkey = "";
//OAuth コンシューマキー・シークレット
$conkey_sec = "";
//設置するウェブサイト名称
$site_name = "はてなハイク 非公式モバイル版";
//サイト名のキャプション
$site_name_caption = "";
//セッションクッキーの有効期間（秒）
$session_cookie_expire = 60 * 60 * 24 * 7;
//セッションデータの有効期間（秒）
$session_file_lifetime = $session_cookie_expire;
//セッションデータの一時保存ディレクトリ
$custom_session_save_path = 'default';
//セッションファイルに対するガベージコレクタの作動率（array(分子, 分母)）
//array('default','default') ならサーバの設定が使われる。
$session_gc_prob = array('1', '100');
//画像縮小用のモバイルゲートウェイの URL
$mobile_gateway_for_images = 'http://mgw.hatena.ne.jp/?';
//スタイルシートへのパス
$style_sheet = './style.php';
//****************************************************
//各ページに共通のフッタを記入する。
$footer = <<<EOL
<div id="footer">
<address>
はてなハイク by <a href="http://mobile.hatena.ne.jp/">はてな</a><br />
{$product_name_abbr} PHP scripts by <a href="{$mobile_gateway}{$project_url}">{$project_name}</a><br />
設置者:<a href="{$mobile_gateway}{$admin_url}">$admin_name</a><br />
<a href="./about.php">{$product_name_abbr} について</a>
</address>
</div>
EOL;
//ログインページに表示する注意書き。
$login_notice = <<<EOL
<div class="notice">
<ul>
<li>上のリンクを開き、{$product_name_abbr} に読み書きの許可を与えてください。</li>
<li>OAuth 認証の仕組みを利用して、はてなから情報を読み書きするための権限を取得します。</li>
<li>ログインするには、Cookie に対応しているブラウザが必要です。</li>
<li>セッション Cookie / サーバ側セッションデータの有効期間は {$session_cookie_expire} / {$session_file_lifetime} 秒に設定されています。</li>
<li>セッションが有効な間でも通信エラーなどが発生した際にログイン状態が解除されることがあります。</li>
<li>取得した認証情報は、この {$product_name_abbr} が設置されているサーバに一時的に保存され、投稿などの際にはてなに送信されます。利用後、サーバから明示的に消去したい場合は、ログアウトしてください。</li>
</ul>
</div>
EOL;
?>

==> yanmah2-1.6-noarch.zip: yanmah2-1.6-noarch/configurable_variables.php <==
<?php
//YANMAH2 - Yet ANother Mobile Accelerated HatenaHaiku
//(c) 2010 YANMAH2 project
//This program is freesoftware. you can redistribute it and/ormodify it under the terms of the [GNU Affero GPL v3](http://www.gnu.org/licenses/agpl.html).
?>
<?php defined("HELLO") or exit(); ?>
<?php
//****************************************************
//このプログラムを設置・管理する責任者名を記入する。
$admin_name = "ここに設置者の名前を記入";
//上の設置者と連絡をとる手段、またはその情報を含む URLを記入する。
$admin_url = "http://h.example.ne.jp/user/";
//****************************************************
//エントリの表示文字数制限の基準値（文字幅）
$entry_limit = 560;
//インクルードパスの設定。"default" でシステムの設定をそのまま使用する。
//パスを記入するとそのパスが追加される。
$extra_include_path = "default";
//モバイルゲートウェイの URL
$mobile_gateway = "http://www.google.co.jp/gwt/n?u=";
//ハイク公式の URL
$haiku_official_url = "http://h.hatena.ne.jp/mobile/";
//API のベース URL
$api_base_url = "http://h.hatena.ne.jp/api/";
//OAuth コンシューマキー
$conkey = "";
//OAuth コンシューマキー・シークレット
$conkey_sec = "";
//設置するウェブサイト名称
$site_name = "はてなハイク 非公式モバイル版";
//サイト名のキャプション
$site_name_caption = "";
//セッションクッキーの有効期間（秒）
$session_cookie_expire = 60 * 60 * 24 * 7;
//セッションデータの有効期間（秒）
$session_file_lifetime = $session_cookie_expire;
//セッションデータの一時保存ディレクトリ
$custom_session_save_path = 'default';
//セッションファイルに対するガベージコレクタの作動率（array(分子, 分母)）
//array('default','default') ならサーバの設定が使われる。
$session_gc_prob = array('1', '100');
//画像縮小用のモバイルゲートウェイの URL
$mobile_gateway_for_images = 'http://mgw.hatena.ne.jp/?';
//スタイルシートへのパス
$style_sheet = './style.php';
//****************************************************
//各ページに共通のフッタを記入する。
$footer = <<<EOL
<div id="footer">
<address>
はてなハイク by <a href="http://mobile.hatena.ne.jp/">はてな</a><br />
{$product_name_abbr} PHP scripts by <a href="{$mobile_gateway}{$project_url}">{$project_name}</a><br />
設置者:<a href="{$mobile_gateway}{$admin_url}">$admin_name</a><br />
<a href="./about.php">{$product_name_abbr} について</a>
</address>
</div>
EOL;
//ログインページに表示する注意書き。
$login_notice = <<<EOL
<div class="notice">
<ul>
<li>上のリンクを開き、{$product_name_abbr} に読み書きの許可を与えてください。</li>
<li>OAuth 認証の仕組みを利用して、はてなから情報を読み書きするための権限を取得します。</li>
<li>ログインするには、Cookie に対応しているブラウザが必要です。</li>
<li>セッション Cookie / サーバ側セッションデータの有効期間は {$session_cookie_expire} / {$session_file_lifetime} 秒に設定されています。</li>
<li>セッションが有効な間でも通信エラーなどが発生した際にログイン状態が解除されることがあります。</li>
<li>取得した認証情報は、この {$product_name_abbr} が設置されているサーバに一時的に保存され、投稿などの際にはてなに送信されます。利用後、サーバから明示的に消去したい場合は、ログアウトしてください。</li>
</ul>
</div>
EOL;
?>
